@@ -2,7 +2,6 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 
-from __future__ import with_statement
 import sys, os
 DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
     '..', '..', '..', '..', '..', 'trytond')))
@@ -12,7 +11,8 @@ if os.path.isdir(DIR):
 import unittest
 from decimal import Decimal
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view
+from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view,\
+    test_depends
 from trytond.transaction import Transaction
 
 class ProductTestCase(unittest.TestCase):
@@ -31,11 +31,18 @@ class ProductTestCase(unittest.TestCase):
         '''
         test_view('product')
 
+    def test0006depends(self):
+        '''
+        Test depends.
+        '''
+        test_depends()
+
     def test0010uom_non_zero_rate_factor(self):
         '''
         Test uom non_zero_rate_factor constraint.
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             category_id = self.uom_category.create({'name': 'Test'})
             transaction.cursor.commit()
 
@@ -77,7 +84,8 @@ class ProductTestCase(unittest.TestCase):
         '''
         Test uom check_factor_and_rate constraint.
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             category_id = self.uom_category.search([
                 ('name', '=', 'Test'),
                 ], limit=1)[0]
@@ -117,7 +125,7 @@ class ProductTestCase(unittest.TestCase):
             ('centimeter', 'rate'),
             ('Foot', 'factor'),
         ]
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             for name, result in tests:
                 uom_id = self.uom.search([
                     ('name', '=', name),
@@ -137,7 +145,7 @@ class ProductTestCase(unittest.TestCase):
             ('Second', 25, 'Hour', 0.0069444444444444441, 0.01),
             ('Millimeter', 3, 'Inch', 0.11811023622047245, 0.12),
         ]
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             for from_name, qty, to_name, result, rounded_result in tests:
                 from_uom = self.uom.browse(self.uom.search(
                     [
@@ -170,7 +178,7 @@ class ProductTestCase(unittest.TestCase):
             ('Second', Decimal('25'), 'Hour', Decimal('90000')),
             ('Millimeter', Decimal('3'), 'Inch', Decimal('76.2')),
         ]
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             for from_name, price, to_name, result in tests:
                 from_uom = self.uom.browse(self.uom.search(
                     [
